!$Header: /home/ssipsl/CVSREP/ORCHIDEE/src_parameters/constantes_soil.f90,v 1.7 2007/05/28 15:21:42 ssipsl Exp $
!IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!-
MODULE constantes_soil
!!--------------------------------------------------------------------
!! "constantes_soil" module contains public data for the soils
!!--------------------------------------------------------------------
  USE constantes
!-
  IMPLICIT NONE
!
  LOGICAL, SAVE                                     :: check_waterbal=.TRUE. !! The check the water balance
  LOGICAL, SAVE                                     :: waterbal_error=.FALSE. !! If true the water balance is bad
!-
! Dimensioning parameters
!-
! Number of soil level
  INTEGER(i_std),PARAMETER :: ngrnd=7
! Number of diagnostic levels in the soil
  INTEGER(i_std),PARAMETER :: nbdl=11
! Number of levels max in CWRR. nslm=nbdl or nslm>nslm in case of
! variable soil depth. Be careful not to assume equality in the code
  INTEGER(i_std),SAVE :: nslm=11
! Maximum depth of soil reservoir. It is fixed accordingly to nslm above (11 -> 2)
! If a depth map is given, nbdl, and nslm will be put to nslm_max and dpu_max will be changed
! in intersurf
  REAL(r_std),SAVE :: dpu_max=2.0_r_std
! Number of levels min and max in CWRR (used only when a depth map is given)
  INTEGER(i_std),PARAMETER :: nslm_min=10
  INTEGER(i_std),PARAMETER :: nslm_max=13
! Number of soil textures (Silt, Sand, Clay)
  INTEGER(i_std),PARAMETER :: ntext=3
! Number of soil tiles
  INTEGER(i_std), PARAMETER :: nstm=3
! Number of soil classes
! For FAO Classification
  INTEGER(i_std),PARAMETER :: nscm_fao=3
! For USDA Classification
  INTEGER(i_std),PARAMETER :: nscm_usda=12

  INTEGER(i_std), SAVE     :: nscm=nscm_fao
!-
!- Parameters for soil thermodynamics
!-
! Average Thermal Conductivity of soils
  REAL(r_std),PARAMETER :: so_cond = 1.5396
! Average Heat capacity of soils
  REAL(r_std),PARAMETER :: so_capa = 2.0514e+6
!-
! Values taken from : PIELKE,'MESOSCALE METEOROLOGICAL MODELING',P.384
! Dry soil heat capacity was decreased and conductivity increased.
!-
! Dry soil Heat capacity of soils
!*REAL(r_std),PARAMETER :: so_capa_dry = 1.35e+6
  REAL(r_std),PARAMETER :: so_capa_dry = 1.80e+6
! Dry soil Thermal Conductivity of soils
!*REAL(r_std),PARAMETER :: so_cond_dry = 0.28
  REAL(r_std),PARAMETER :: so_cond_dry = 0.40
!-
! Wet soil Heat capacity of soils
  REAL(r_std),PARAMETER :: so_capa_wet = 3.03e+6
! Wet soil Thermal Conductivity of soils
  REAL(r_std),PARAMETER :: so_cond_wet = 1.89
!-
! Thermal Conductivity of snow
  REAL(r_std),PARAMETER :: sn_cond = 0.3
! Snow density for the soil thermodynamics
  REAL(r_std),PARAMETER :: sn_dens = 330.0
! Heat capacity for snow
  REAL(r_std),PARAMETER :: sn_capa = 2100.0_r_std*sn_dens
!-
! Constantes from the Choisnel hydrology
!-
! Wilting point (Has a numerical role for the moment)
  REAL(r_std),PARAMETER :: qwilt = 5.0
! Total depth of soil reservoir (for hydrolc)
  REAL(r_std),SAVE :: dpu_cste=2.0_r_std
! The minimal size we allow for the upper reservoir (m)
  REAL(r_std),PARAMETER :: min_resdis = 2.e-5
! Diffusion constant for the slow regime
! (This is for the diffusion between reservoirs)
  REAL(r_std),PARAMETER :: min_drain = 0.001
! Diffusion constant for the fast regime
  REAL(r_std),PARAMETER :: max_drain = 0.1
! The exponential in the diffusion law
  REAL(r_std),PARAMETER :: exp_drain = 1.5
! Transforms leaf area index into size of interception reservoir
  REAL(r_std),SAVE :: qsintcst = 0.1
! Maximum quantity of water (Kg/M3)
  REAL(r_std),PARAMETER :: mx_eau_eau = 150.
!-
! Constant in the computation of resistance for bare  soil evaporation
 REAL(r_std),PARAMETER :: rsol_cste = 33.E3
! Scaling depth for litter humidity (m)
  REAL(r_std),PARAMETER :: hcrit_litter=0.03

! Default mean slope coefficient for reinfiltration
  REAL(r_std),SAVE :: slope_default=0.1

!-
! Parameters specific for the CWRR hydrology.
!-

!-
!- 1. Parameters for FAO Classification
!-

!-
! Parameters for soil type distribution
!-
! Default soil texture distribution in the following order :
!   COARSE, MEDIUM, FINE
  REAL(r_std),DIMENSION(nscm_fao),SAVE :: soilclass_default_fao = &
 & (/ 0.28, 0.52, 0.20 /)
  REAL(r_std),DIMENSION(nscm_fao*2-1),SAVE :: soilclass_default_fao2 = &
 & (/ 0.28, 0.0, 0.52, 0.0, 0.20 /)
  INTEGER, SAVE :: jsc_default = 2
! Van genuchten coefficient n
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: nvan_fao = &
 & (/ 1.89_r_std, 1.56_r_std, 1.31_r_std /)
! Van genuchten coefficient a (cm^{-1}) BIG BUG -> mm^{-1}
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: avan_fao = &
 & (/ 0.0075_r_std, 0.0036_r_std, 0.0019_r_std /) 
!  & (/ 0.075_r_std, 0.036_r_std, 0.019_r_std /) 
! & (/ 0.036_r_std, 0.036_r_std, 0.036_r_std /)
! Residual soil water content
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: mcr_fao = &
 & (/ 0.065_r_std, 0.078_r_std, 0.095_r_std /)
! Saturated soil water content
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: mcs_fao = &
 & (/ 0.41_r_std, 0.43_r_std, 0.41_r_std /)
! Hydraulic conductivity Saturation (mm/d)
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: ks_fao = &
 & (/ 1060.8_r_std, 249.6_r_std, 62.4_r_std /)
! Fraction of saturated volumetric soil moisture above which transpir is max
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: pcent_fao = &
 & (/ 0.5_r_std, 0.5_r_std, 0.5_r_std /)
! Max value of the permeability coeff at the bottom of the soil
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: free_drain_max_fao = &
 & (/ 1.0_r_std, 1.0_r_std, 1.0_r_std /)
! Volumetric water content field capacity
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: mcf_fao = &
 & (/ 0.32_r_std, 0.32_r_std, 0.32_r_std /)
! Volumetric water content Wilting pt
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: mcw_fao = &
 & (/ 0.10_r_std, 0.10_r_std, 0.10_r_std /)
! & (/ 0.07_r_std, 0.085_r_std, 0.10_r_std /)
! Vol. wat. cont. above which albedo is cst
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: mc_awet_fao = &
 & (/ 0.25_r_std, 0.25_r_std, 0.25_r_std /)
! Vol. wat. cont. below which albedo is cst
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: mc_adry_fao = &
 & (/ 0.1_r_std, 0.1_r_std, 0.1_r_std /)
! Matrix potential at saturation (mm)
  REAL(r_std),PARAMETER,DIMENSION(nscm_fao) :: psis_fao = &
 & (/ -300.0_r_std, -300.0_r_std, -300.0_r_std /)

!-
!- 2. Parameters for USDA Classification
!-

!-
! Parameters for soil type distribution
!-
! Default soil texture distribution in the following order :
!    sand, loam and clay ??? OR COARSE, MEDIUM, FINE???
  REAL(r_std),DIMENSION(nscm_usda),SAVE :: soilclass_default_usda = &
 & (/ 0.28, 0.52, 0.20, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 /)

! Van genuchten coefficient n
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: nvan_usda = &
 & (/ 2.68_r_std, 2.28_r_std, 1.89_r_std, 1.41_r_std, &
 &    1.37_r_std, 1.56_r_std, 1.48_r_std, 1.23_r_std, &
 &    1.31_r_std, 1.23_r_std, 1.09_r_std, 1.09_r_std /)
! Van genuchten coefficient a (cm^{-1}) BIG BUG!!! -> mm^{-1}
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: avan_usda = &
 & (/ 0.0145_r_std, 0.0124_r_std, 0.0075_r_std, 0.0020_r_std, &
 &    0.0016_r_std, 0.0036_r_std, 0.0059_r_std, 0.0010_r_std, &
 &    0.0019_r_std, 0.0027_r_std, 0.0005_r_std, 0.0008_r_std /)
! & (/ 0.145_r_std, 0.124_r_std, 0.075_r_std, 0.020_r_std, &
! &    0.016_r_std, 0.036_r_std, 0.059_r_std, 0.010_r_std, &
! &    0.019_r_std, 0.027_r_std, 0.005_r_std, 0.008_r_std /)
! Sand, Loamy Sand, Sandy Loam, Silt Loam, Silt, Loam, Sandy Clay Loam, Silty Clay Loam, Clay Loam, Sandy Clay, Silty Clay, Clay
! Residual soil water content
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: mcr_usda = &
 & (/ 0.045_r_std, 0.057_r_std, 0.065_r_std, 0.067_r_std, &
 &    0.034_r_std, 0.078_r_std, 0.100_r_std, 0.089_r_std, &
 &    0.095_r_std, 0.100_r_std, 0.070_r_std, 0.068_r_std /)
! Saturated soil water content
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: mcs_usda = &
 & (/ 0.43_r_std, 0.41_r_std, 0.41_r_std, 0.45_r_std, &
 &    0.46_r_std, 0.43_r_std, 0.39_r_std, 0.43_r_std, &
 &    0.41_r_std, 0.38_r_std, 0.36_r_std, 0.38_r_std /)
! Hydraulic conductivity Saturation (mm/d)
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: ks_usda = &
 & (/ 7128.0_r_std, 3501.6_r_std, 1060.8_r_std, 108.0_r_std, &
 &    60.0_r_std, 249.6_r_std, 314.4_r_std, 16.8_r_std, &
 &    62.4_r_std, 28.8_r_std, 4.8_r_std, 48.0_r_std /)
! Soil moisture above which transpir is max
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: pcent_usda = &
 & (/ 0.5_r_std, 0.5_r_std, 0.5_r_std, 0.5_r_std, & 
 &    0.5_r_std, 0.5_r_std, 0.5_r_std, 0.5_r_std, & 
 &    0.5_r_std, 0.5_r_std, 0.5_r_std, 0.5_r_std /) 
! Max value of the permeability coeff at the bottom of the soil
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: free_drain_max_usda = &
 & (/ 1.0_r_std, 1.0_r_std, 1.0_r_std, 1.0_r_std, &
 &    1.0_r_std, 1.0_r_std, 1.0_r_std, 1.0_r_std, &
 &    1.0_r_std, 1.0_r_std, 1.0_r_std, 1.0_r_std /)
! Volumetric water content field capacity
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: mcf_usda = &
 & (/ 0.32_r_std, 0.32_r_std, 0.32_r_std, 0.32_r_std, &
 &    0.32_r_std, 0.32_r_std, 0.32_r_std, 0.32_r_std, &
 &    0.32_r_std, 0.32_r_std, 0.32_r_std, 0.32_r_std /)
! Volumetric water content Wilting pt
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: mcw_usda = &
 & (/ 0.10_r_std, 0.10_r_std, 0.10_r_std, 0.10_r_std, &
 &    0.10_r_std, 0.10_r_std, 0.10_r_std, 0.10_r_std, &
 &    0.10_r_std, 0.10_r_std, 0.10_r_std, 0.10_r_std /)
! Vol. wat. cont. above which albedo is cst
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: mc_awet_usda = &
 & (/ 0.25_r_std, 0.25_r_std, 0.25_r_std, 0.25_r_std, &
 &    0.25_r_std, 0.25_r_std, 0.25_r_std, 0.25_r_std, &
 &    0.25_r_std, 0.25_r_std, 0.25_r_std, 0.25_r_std /)
! Vol. wat. cont. below which albedo is cst
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: mc_adry_usda = &
 & (/ 0.1_r_std, 0.1_r_std, 0.1_r_std, 0.1_r_std, &
 &    0.1_r_std, 0.1_r_std, 0.1_r_std, 0.1_r_std, &
 &    0.1_r_std, 0.1_r_std, 0.1_r_std, 0.1_r_std /)
! Matrix potential at saturation (mm)
  REAL(r_std),PARAMETER,DIMENSION(nscm_usda) :: psis_usda = &
 & (/ -300.0_r_std, -300.0_r_std, -300.0_r_std, -300.0_r_std, &
 &    -300.0_r_std, -300.0_r_std, -300.0_r_std, -300.0_r_std, &
 &    -300.0_r_std, -300.0_r_std, -300.0_r_std, -300.0_r_std /)

! CWRR linearisation
  INTEGER(i_std),PARAMETER :: imin = 1
! number of interval for CWRR
  INTEGER(i_std),PARAMETER :: nbint = 50
! number of points for CWRR
  INTEGER(i_std),PARAMETER :: imax = nbint+1
! Time weighting for discretisation
  REAL(r_std),PARAMETER :: w_time = 1.0_r_std
!-
! Diagnostic variables
!-
! The lower limit of the layer on which soil moisture (relative)
! and temperature are going to be diagnosed.
! These variables are made for transfering the information
! to the biogeophyical processes modelled in STOMATE.
!
!- diag_lev is computed until nslm_max in order to provide the depth
!- for the outputs if the soil depth is variable
REAL(r_std),DIMENSION(nslm_max),SAVE :: diaglev 
!-------------------------
END MODULE constantes_soil
