Linux  R2.6.5-7.283-default FORTRAN90/SX         Rev.360        Wed Oct 22 11:36:36 2008
FILE NAME: i.stomate_prescribe.f90
PROGRAM NAME: stomate_prescribe
DIAGNOSTIC LIST

  LINE  LEVEL( NO.): DIAGNOSTIC MESSAGE

    89  vec  (   2): Partially vectorized loop.
    89  vec  (  25): Work vectors are used. Size=48byte
    99  vec  (   4): Vectorized array expression.
   107  vec  (   4): Vectorized array expression.
   109  vec  (   3): Unvectorized loop.
   109  vec  (  13): Overhead of loop division is too large.
   131  opt  (1036): Potential feedback - use directive if OK.
   164  vec  (   4): Vectorized array expression.
   180  vec  (   4): Vectorized array expression.
   190  vec  (   4): Vectorized array expression.
   202  opt  (1057): Complicated use of variable inhibits loop optimization.
   219  vec  (   3): Unvectorized loop.
   219  vec  (  13): Overhead of loop division is too large.
   230  vec  (   4): Vectorized array expression.
   230  vec  (  26): Macro operation Sum/InnerProd.
   234  vec  (   4): Vectorized array expression.
   245  vec  (  18): Unvectorizable data type.
   258  vec  (   4): Vectorized array expression.
   258  vec  (  26): Macro operation Sum/InnerProd.
   291  warn (  83): Dummy argument "space_nat" is not used.
Linux  R2.6.5-7.283-default FORTRAN90/SX         Rev.360        Wed Oct 22 11:36:36 2008
FILE NAME: i.stomate_prescribe.f90
PROGRAM NAME: stomate_prescribe
FORMAT LIST

  LINE    LOOP     FORTRAN STATEMENT

     1:            ! Initialize density of individuals and crown area to some reasonable value
     2:            !   if the DGVM is not (yet) activated.
     3:            ! Prescribe density of individuals and crown area for agricultural PFTs.
     4:            ! At first call, if the DGVM is not (yet) activated, impose some biomass if zero
     5:            !   for a prescribed PFT. Initialize leaf age classes.
     6:            ! At first call, if the DGVM is not (yet) activated, declare PFT present if its 
     7:            !   prescribed vegetation cover is above 0
     8:            !
     9:            ! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/stomate_prescribe.f90,v 1.9 2007/05/28 14:49:02 ssipsl Exp $
    10:            ! IPSL (2006)
    11:            !  This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
    12:            !
    13:            MODULE stomate_prescribe
    14:            
    15:              ! modules used:
    16:            
    17:              USE ioipsl
    18:              USE stomate_constants
    19:            
    20:              IMPLICIT NONE
    21:            
    22:              ! private & public routines
    23:            
    24:              PRIVATE
    25:              PUBLIC prescribe,prescribe_clear
    26:            
    27:                ! first call
    28:                LOGICAL, SAVE                                              :: firstcall = .TRUE.
    29:            
    30:            CONTAINS
    31:            
    32:              SUBROUTINE prescribe_clear
    33:                firstcall=.TRUE.
    34:              END SUBROUTINE prescribe_clear
    35:             
    36:             SUBROUTINE prescribe (npts, &
    37:                                    space_nat, &
    38:                                    veget_max, PFTpresent, everywhere, when_growthinit, &
    39:                                    biomass, leaf_frac, ind, cn_ind)
    40:            
    41:                !
    42:                ! 0 declarations
    43:                !
    44:            
    45:                ! 0.1 input
    46:            
    47:                ! Domain size
    48:                INTEGER(i_std), INTENT(in)                                        :: npts
    49:                ! total natural space (fraction of total space)
    50:                REAL(r_std), DIMENSION(npts), INTENT(in)                    :: space_nat
    51:            
    52:                ! 0.2 modified fields
    53:            
    54:                ! "maximal" coverage fraction of a PFT (LAI -> infinity) on nat/agri ground
    55:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)            :: veget_max
    56:                ! PFT present
    57:                LOGICAL, DIMENSION(npts,npft), INTENT(inout)               :: PFTpresent
    58:                ! is the PFT everywhere in the grid box or very localized (after its introduction)
    59:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)            :: everywhere
    60:                ! how many days ago was the beginning of the growing season
    61:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)            :: when_growthinit
    62:                ! biomass (gC/(m**2 of nat/agri ground))
    63:                REAL(r_std), DIMENSION(npts,npft,nparts), INTENT(inout)     :: biomass
    64:                ! fraction of leaves in leaf age class
    65:                REAL(r_std), DIMENSION(npts,npft,nleafages), INTENT(inout)  :: leaf_frac
    66:                ! density of individuals (1/(m**2 of nat/agri ground))
    67:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)            :: ind
    68:                ! crown area of individuals (m**2)
    69:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)            :: cn_ind
    70:            
    71:                ! 0.3 output
    72:            
    73:            
    74:                ! 0.4 local
    75:            
    76:                ! generic tree crown area (m**2)
    77:                REAL(r_std), PARAMETER                                      :: cn_tree = 4.
    78:                ! stem diameter (m)
    79:                REAL(r_std), DIMENSION(npts)                                :: dia
    80:                ! woodmass (gC/(m**2 of nat/agri ground))
    81:                REAL(r_std), DIMENSION(npts)                                :: woodmass
    82:                ! woodmass of an individual (gC)
    83:                REAL(r_std), DIMENSION(npts)                                :: woodmass_ind
    84:                ! index
    85:                INTEGER(i_std)                                             :: i,j
    86:            
    87:                ! =========================================================================
    88:            
    89: V------>       DO j = 1, npft
    90: |          
    91: |                ! only when the DGVM is not activated or agricultural PFT.
    92: |          
    93: |       S        IF ( ( .NOT. control%ok_dgvm ) .OR. ( .NOT. natural(j) ) ) THEN
    94: |          
    95: |                  !
    96: |                  ! 1 crown area
    97: |                  !
    98: |          
    99: |V=====            cn_ind(:,j) = 0.0
   100: |          
   101: |       S          IF ( tree(j) ) THEN
   102: |          
   103: |                    !
   104: |                    ! 1.1 trees
   105: |                    !
   106: |          
   107: |V=====              dia(:) = 0.0
   108: |          
   109: |+----->             DO i = 1, npts
   110: ||         
   111: ||                     IF ( veget_max(i,j) .GT. 0.0 ) THEN
   112: ||         
   113: ||                       ! 1.1.1 calculate total wood mass
   114: ||         
   115: ||                       woodmass(i) = biomass(i,j,isapabove) + biomass(i,j,isapbelow) + &
   116: ||                                     biomass(i,j,iheartabove) + biomass(i,j,iheartbelow) 
   117: ||         
   118: ||                       IF ( woodmass(i) .GT. min_stomate ) THEN
   119: ||         
   120: ||                         ! 1.1.2 calculate critical density of individuals
   121: ||         
   122: ||                         ind(i,j) = woodmass(i) / &
   123: ||                                    ( pipe_density*pi/4.*pipe_tune2 * maxdia(j)**(2.+pipe_tune3) )
   124: ||         
   125: ||                         ! 1.1.3 individual biomass corresponding to this critical density of individuals
   126: ||         
   127: ||                         woodmass_ind(i) = woodmass(i) / ind(i,j)
   128: ||         
   129: ||                         ! 1.1.4 stem diameter
   130: ||         
   131: ||                         dia(i) = ( woodmass_ind(i) / ( pipe_density * pi/4. * pipe_tune2 ) ) ** &
   132: ||                                  ( 1. / ( 2. + pipe_tune3 ) )
   133: ||         
   134: ||                         ! 1.1.5 crown area, provisional
   135: ||         
   136: ||                         cn_ind(i,j) = pipe_tune1 * MIN( maxdia(j), dia(i) ) ** 1.6
   137: ||         
   138: ||                         ! 1.1.6 do we have to recalculate the crown area?
   139: ||         
   140: ||                         IF ( cn_ind(i,j) * ind(i,j) .GT. 1.002* veget_max(i,j) ) THEN
   141: ||         
   142: ||                           ind(i,j) = veget_max(i,j) / cn_ind(i,j)
   143: ||         
   144: ||                         ELSE
   145: ||         
   146: ||                           ind(i,j) = ( veget_max(i,j) / &
   147: ||                                        ( pipe_tune1 * (woodmass(i)/(pipe_density*pi/4.*pipe_tune2))**(1.6/(2.+pipe_tune3)) ) ) &
   148: ||                                      ** (1./(1.-(1.6/(2.+pipe_tune3))))
   149: ||         
   150: ||                           woodmass_ind(i) = woodmass(i) / ind(i,j)
   151: ||         
   152: ||                           dia(i) = ( woodmass_ind(i) / ( pipe_density * pi/4. * pipe_tune2 ) ) ** &
   153: ||                                    ( 1. / ( 2. + pipe_tune3 ) )
   154: ||         
   155: ||                           ! final crown area
   156: ||                           cn_ind(i,j) = pipe_tune1 * MIN( maxdia(j), dia(i) ) ** 1.6
   157: ||         
   158: ||                         ENDIF
   159: ||         
   160: ||                       ELSE
   161: ||         
   162: ||                         ! woodmass = 0 => impose some value
   163: ||         
   164: ||V====                    dia(:) = maxdia(j)
   165: ||         
   166: ||                         cn_ind(i,j) = pipe_tune1 * MIN( maxdia(j), dia(i) ) ** 1.6
   167: ||         
   168: ||                       ENDIF
   169: ||         
   170: ||                     ENDIF    ! veget_max .GT. 0.
   171: ||         
   172: |+-----              ENDDO      ! loop over grid points
   173: |          
   174: |                  ELSE
   175: |          
   176: |                    !
   177: |                    ! 1.2 grasses: always 1m**2
   178: |                    !
   179: |          
   180: |V----->             WHERE ( veget_max(:,j) .GT. 0.0 )
   181: |V-----                cn_ind(:,j) = 1.0
   182: |                    ENDWHERE
   183: |          
   184: |                  ENDIF   ! tree/grass?
   185: |          
   186: |                  !
   187: |                  ! 2 density of individuals
   188: |                  !
   189: |          
   190: |V----->           WHERE ( veget_max(:,j) .GT. 0.0 )
   191: ||         
   192: ||                   ind(:,j) = veget_max(:,j) / cn_ind(:,j)
   193: ||         
   194: ||                 ELSEWHERE
   195: ||         
   196: |V-----              ind(:,j) = 0.0
   197: |          
   198: |                  ENDWHERE
   199: |          
   200: |                ENDIF     ! not natural or DGVM not activated?
   201: |          
   202: V------        ENDDO       ! loop over PFTs
   203:            
   204:                !
   205:                ! 4 first call
   206:                !
   207:            
   208:                IF ( firstcall ) THEN
   209:            
   210:                  WRITE(numout,*) 'prescribe:'
   211:            
   212:                  ! impose some biomass if zero and PFT prescribed
   213:            
   214:                  WRITE(numout,*) '   > Imposing initial biomass for prescribed trees, '// &
   215:                                  'initial reserve mass for prescribed grasses.'
   216:                  WRITE(numout,*) '   > Declaring prescribed PFTs present.'
   217:            
   218: +------>         DO j = 1, npft
   219: |+----->           DO i = 1, npts
   220: ||         
   221: ||                   ! is vegetation static or PFT agricultural?
   222: ||         
   223: ||                   IF ( ( .NOT. control%ok_dgvm ) .OR. &
   224: ||                        ( ( .NOT. natural(j) ) .AND. ( veget_max(i,j) .GT. min_stomate ) ) ) THEN
   225: ||         
   226: ||                     !
   227: ||                     ! 4.1 trees 
   228: ||                     !
   229: ||         
   230: ||V====                IF ( tree(j) .AND. &
   231: ||                          ( veget_max(i,j) .GT. min_stomate ) .AND. &
   232: ||                          ( SUM( biomass(i,j,:) ) .LE. min_stomate ) ) THEN
   233: ||         
   234: ||V====                  biomass(i,j,:) = 40. * bm_sapl(j,:) * ind(i,j)
   235: ||         
   236: ||                       ! set leaf age classes
   237: ||+====                  leaf_frac(i,j,:) = 0.0
   238: ||                       leaf_frac(i,j,1) = 1.0
   239: ||         
   240: ||                       ! set time since last beginning of growing season
   241: ||                       when_growthinit(i,j) = large_value
   242: ||         
   243: ||                       ! seasonal trees: no leaves at beginning
   244: ||         
   245: ||                       IF ( pheno_crit%pheno_model(j) .NE. 'none' ) THEN
   246: ||         
   247: ||                         biomass(i,j,ileaf) = 0.0
   248: ||                         leaf_frac(i,j,1) = 0.0
   249: ||         
   250: ||                       ENDIF
   251: ||         
   252: ||                     ENDIF
   253: ||         
   254: ||                     !
   255: ||                     ! 4.2 grasses
   256: ||                     !
   257: ||         
   258: ||V====                IF ( ( .NOT. tree(j) ) .AND. &
   259: ||                          ( veget_max(i,j) .GT. min_stomate ) .AND. &
   260: ||                          ( SUM( biomass(i,j,:) ) .LE. min_stomate ) ) THEN
   261: ||         
   262: ||                       biomass(i,j,icarbres) = bm_sapl(j,icarbres) * ind(i,j)
   263: ||         
   264: ||                       ! set leaf age classes
   265: ||*====                  leaf_frac(i,j,:) = 0.0
   266: ||                       leaf_frac(i,j,1) = 1.0
   267: ||         
   268: ||                       ! set time since last beginning of growing season
   269: ||                       when_growthinit(i,j) = large_value
   270: ||         
   271: ||                     ENDIF
   272: ||         
   273: ||                     !
   274: ||                     ! 4.3 declare PFT present everywhere in that grid box
   275: ||                     !
   276: ||         
   277: ||                     IF ( veget_max(i,j) .GT. min_stomate ) THEN
   278: ||                       PFTpresent(i,j) = .TRUE.
   279: ||                       everywhere(i,j) = 1.
   280: ||                     ENDIF
   281: ||         
   282: ||                   ENDIF   ! not control%ok_dgvm  or agricultural
   283: ||         
   284: |+-----            ENDDO
   285: +------          ENDDO
   286:            
   287:                  firstcall = .FALSE.
   288:            
   289:                ENDIF
   290:            
   291:              END SUBROUTINE prescribe
   292:            
   293:            END MODULE stomate_prescribe
